@@ -30,10 +30,10 @@ double static **Marginals(double* theta, int maxsize)
 
 SEXP ReprodEstimates(SEXP nvec, SEXP rvec, SEXP freqvec)
 {
- double *theta, *thetanew, sqerror, **marg;
+ double *theta, *thetanew, abserror, **marg;
  int i, maxsize, nr, ntot, r, ri, ni, n, fri, start;
  SEXP res;
- const double eps=1e-8;
+ const double eps=1e-16;
  
  nr = LENGTH(nvec);
  maxsize = 0;
@@ -51,10 +51,10 @@ SEXP ReprodEstimates(SEXP nvec, SEXP rvec, SEXP freqvec)
  for (r=0; r<=maxsize; r++){
          theta[r] = 1.0/(maxsize+1);
  }
- sqerror = 1;
+ abserror = 1;
  //EM update
- while (sqerror>eps){
-         sqerror = 0;
+ while (abserror>eps){
+         abserror = 0;
          marg = Marginals(theta, maxsize);
          for (r=0; r<=maxsize; r++) thetanew[r] = 0;
          for (i=0; i<nr; i++){
@@ -63,12 +63,12 @@ SEXP ReprodEstimates(SEXP nvec, SEXP rvec, SEXP freqvec)
                  fri = INTEGER(freqvec)[i];
                  for (r=ri; r<=maxsize-ni+ri; r++){
                          thetanew[r] += choose(ni,ri)*choose(maxsize-ni,r-ri)*theta[r]*fri*1.0/
-                                        marg[ni][ri];
+                                        marg[ni][ri] ;
                  }
          }
          for (r=0; r<=maxsize; r++){
                  thetanew[r] = thetanew[r]/(ntot*choose(maxsize,r)*1.0);
-                 sqerror += R_pow_di(thetanew[r]-theta[r],2);
+                 abserror += fabs(thetanew[r]-theta[r]);
                  theta[r] = thetanew[r];
          }
          for(n = 0; n <= maxsize; n++) free(marg[n]);
@@ -544,8 +544,11 @@ SEXP ReprodISDM(SEXP Q, SEXP S, SEXP tab, SEXP MaxIter, SEXP MaxDirections,
   }
  free(marg);
 
- 
  PROTECT(res = allocVector(VECSXP,5));
+  if (asInteger(verbose)==1) 
+   Rprintf("Limit=%d; %d Iterations; Limit enforced %d times (%4.2f percent)\n", 
+           limit, niter, nenforced, nenforced*100.0/niter);
+
   SET_VECTOR_ELT(res, 0, margSXP);
   SET_VECTOR_ELT(res, 1, Q);
   SET_VECTOR_ELT(res, 2, D);
@@ -556,10 +559,6 @@ SEXP ReprodISDM(SEXP Q, SEXP S, SEXP tab, SEXP MaxIter, SEXP MaxDirections,
   SET_VECTOR_ELT(res, 4, tmp);
  UNPROTECT(4);   //tmp, res, margSXP, D
 
- if (asInteger(verbose)==1) 
-   Rprintf("Limit=%d; %d Iterations; Limit enforced %d times (%4.2f percent)\n", 
-           limit, niter, nenforced, nenforced*100.0/niter);
-
  return res;
 
 } 
